.. role:: hidden
    :class: hidden-section

gpytorch.utils
===================================

.. currentmodule:: gpytorch.utils
.. automodule:: gpytorch.utils
   :members:

Grid Utilities
----------------------

.. automodule:: gpytorch.utils.grid
   :members:

Interpolation Utilities
---------------------------------

.. automodule:: gpytorch.utils.interpolation
   :members:

Nearest Neighbors Utilities
---------------------------------

.. automodule:: gpytorch.utils.nearest_neighbors
   :members:

Quadrature Utilities
----------------------------

.. automodule:: gpytorch.utils.quadrature
   :members:

Transform Utilities
--------------------------

.. automodule:: gpytorch.utils.transforms
   :members:
